# Deep Glue

<img src="https://raw.githubusercontent.com/EricThomson/deepglue/main/docs/images/deep_glue_logo.png" alt="deepglue logo" align="right" width="180">

Utilities for pytorch projects: keeping all the useful stuff together in one place.

Installation: `pip install deepglue`.

Use: `import deepglue as dg`

Docs: https://deepglue.readthedocs.io/en/latest/ 

Deep Glue is a rapidly changing work in progress. Consider it in pre-alpha stages.



